@@ -24,6 +24,10 @@ protected:
     bool restoreWidgetState();
     void errorWidget();
     bool x11Event(XEvent *event);
+    void paintEvent(QPaintEvent *event);
+
+public slots:
+  void resizer(QSize size);
 
 public:
     static QuickWidget *createAndShowNew(const QString& fileName, const QSize& size=QSize());
@@ -38,6 +42,9 @@ class QuickWidgetWrapper : public QObject
 {
     Q_OBJECT
 
+Q_SIGNALS:
+    void onHomeScreenChanged();
+
 public:
     QuickWidgetWrapper(QuickWidget *owner) : m_owner(owner) {;}
     Q_PROPERTY(bool isActiveWindow READ onHomeScreen NOTIFY onHomeScreenChanged);
@@ -52,12 +59,12 @@ public:
         emit onHomeScreenChanged();
     }
 
-Q_SIGNALS:
-    void onHomeScreenChanged();
 
 private:
     QuickWidget *m_owner;
     bool homeScreen;
+
+
 };
 
 #endif // QuickWidget_HPP
